BrowserLauncherFactory (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers
Class BrowserLauncherFactory

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.BrowserLauncherFactory

    public class BrowserLauncherFactory

extends java.lang.Object

Returns BrowserLaunchers based on simple strings given by the user

Author:
  danielf

Constructor Summary
`BrowserLauncherFactory()`

Method Summary
`static void` | `addBrowserLauncher(java.lang.String browser, java.lang.Class<? extends BrowserLauncher> clazz)`
`BrowserLauncher` | `getBrowserLauncher(java.lang.String browser, java.lang.String sessionId, RemoteControlConfiguration configuration, BrowserConfigurationOptions browserOptions)` Returns the browser given by the specified browser string
`static java.util.Map<java.lang.String,java.lang.Class<? extends BrowserLauncher>>` | `getSupportedLaunchers()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### BrowserLauncherFactory

    public BrowserLauncherFactory()

Method Detail

### getBrowserLauncher

    public BrowserLauncher getBrowserLauncher(java.lang.String browser,
                                              java.lang.String sessionId,
                                              RemoteControlConfiguration configuration,
                                              BrowserConfigurationOptions browserOptions)

  Returns the browser given by the specified browser string

  Parameters:
    `browser` - a browser string like "*firefox"
    `sessionId` - the sessionId to launch
    `browserOptions` - TODO
  Returns:
    the BrowserLauncher ready to launch

### getSupportedLaunchers

    public static java.util.Map<java.lang.String,java.lang.Class<? extends BrowserLauncher>> getSupportedLaunchers()

### addBrowserLauncher

    public static void addBrowserLauncher(java.lang.String browser,
                                          java.lang.Class<? extends BrowserLauncher> clazz)

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.